@@ -31,7 +31,7 @@ warnings.filterwarnings("ignore")
 
 class accuinsight(Common):
     def __init__(self):
-        global feature_name, alarm, alarm_api, message_param, user_id
+        global feature_name, alarm, alarm_api, message_param, user_id, notebook_info
         super().__init__()
 
         feature_name = None
@@ -40,6 +40,7 @@ class accuinsight(Common):
 
         alarm = self.workspace_alarm
         alarm_api = self.workspace_alarm_api
+        notebook_info = self.notebook_info
 
     def get_file(self, storage_json_file_name=None):
         global save_path, StorageInfo, target_name
@@ -83,6 +84,10 @@ class accuinsight(Common):
         global user_id
         user_id = None
 
+    def set_current_notebook(self):
+        global notebook_info
+        notebook_info = get_current_notebook()
+
     class add_experiment(object):
         def __init__(self, model_name, *args, model_monitor=False):
             self.shap_on = model_monitor
@@ -95,7 +100,7 @@ class accuinsight(Common):
         
             # if in notebook
             if is_in_ipython():
-                self.var_model_file_path = get_current_notebook()
+                self.var_model_file_path = notebook_info
                 _caller_globals = inspect.stack()[1][0].f_globals
                 (
                     self.mainfile,
