@@ -18,7 +18,7 @@ from Accuinsight.modeler.core.Run.RunInfo.RunInfo import set_current_runs, clear
 from Accuinsight.modeler.core.feature_contribution import shap_value
 from Accuinsight.modeler.utils.dl_utils import delete_files_except_best, get_best_model_path
 from Accuinsight.modeler.utils.dependency.dependencies import gather_sources_and_dependencies
-from Accuinsight.modeler.utils.os_getenv import is_in_ipython, get_current_notebook, get_os_env
+from Accuinsight.modeler.utils.os_getenv import is_in_ipython, get_os_env
 from Accuinsight.modeler.clients.modeler_api import LifecycleRestApi
 from Accuinsight.Lifecycle.common import Common
 
@@ -71,7 +71,7 @@ class accuinsight(Common):
 
         # if in notebook
         if is_in_ipython():
-            var_model_file_path = get_current_notebook()
+            var_model_file_path = self.notebook_info
             _caller_globals = inspect.stack()[1][0].f_globals
             (
                 mainfile,
