@@ -124,9 +124,7 @@ def _parse_selected_metrics(run_meta):
     metric_data = load_parameter(run_meta)
 
     grpc_metrics = []
-
-    is_exist = SELECTED_METRICS in metric_data
-    if is_exist is not True:
+    if SELECTED_METRICS not in metric_data:
         return grpc_metrics
 
     # selected_metrics
@@ -229,6 +227,7 @@ def parse_parameter(run_meta):
 
     return _parse_optimizer_info(param_data)
 
+
 def parse_run_result():
     run_info_json = _get_current_run()
     result_dict = {'metrics': None, 'params': None, 'visual': None}
