@@ -9,7 +9,7 @@ from Accuinsight.modeler.utils.os_getenv import get_os_env
 from Accuinsight.modeler.core.Run.ParseRun import BaseParser
 from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_current_run, dict_to_list
 from Accuinsight.modeler.core.LcConst.LcConst import RUN_OBJ_NAME, SOURCE_FILE_GIT_META, PYTHON_DEPENDENCY, \
-    SOURCE_FILE_GIT_REPO, SOURCE_FILE_GIT_COMMIT_ID, RUN_MODEL_JSON_PATH
+    SOURCE_FILE_GIT_REPO, SOURCE_FILE_GIT_COMMIT_ID
 from Accuinsight.modeler.entities.lc_run_info import LcRunInfo as EntityRunInfo
 from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.entities.lc_artifact import LcArtifact as EntityArtifact
@@ -18,7 +18,7 @@ _PATH_PREFIX = ""
 _METHOD_TO_INFO = extract_api_info_for_service(LifecycleService, _PATH_PREFIX)
 
 
-def _run_parser(run_name):
+def _run_parser():
     run_data = BaseParser.run_parser(BaseParser.get_parser_type())
     return run_data
 
@@ -95,7 +95,7 @@ class RestStore(LcAbstractStore):
         user_id = str(env_value[LcConst.ENV_USER_SSO_ID])  # owner id
         language_id = str(env_value[LcConst.ENV_LANGUAGE_ID])
 
-        with open(current_run_meta['result_path'][RUN_MODEL_JSON_PATH]) as run_json_file:
+        with open(current_run_meta[LcConst.RUN_RESULT_PATH][LcConst.RUN_MODEL_JSON_PATH]) as run_json_file:
             json_data = json.load(run_json_file)
 
             try:
@@ -127,7 +127,7 @@ class RestStore(LcAbstractStore):
             )
 
         # to get parameter and metric
-        run_data = _run_parser(run_name)
+        run_data = _run_parser()
         metric_data = run_data['metrics']
         parameter_data = run_data['params']
         visual_data = None
