@@ -39,9 +39,9 @@ def is_in_ipython():
     return False
     
     
-def __list_jupyterlab_workspace(targtet_path):
+def __list_jupyterlab_workspace(target_path):
     file_lists = []
-    for (dirpath, dirnames, filenames) in os.walk(targtet_path):
+    for (dirpath, dirnames, filenames) in os.walk(target_path):
         for fn in filenames:
             if not fn.endswith('.swp'):
                 if 'auto' in fn: continue
@@ -68,7 +68,7 @@ def get_current_notebook():
         # '/home/notebook/.jupyter/lab/workspaces'
         if os.path.isdir(target_path): # if jupyter lab
             return __get_current_file(target_path=target_path,
-                                      target_file=__list_jupyterlab_workspace(targtet_path=target_path)[0]
+                                      target_file=__list_jupyterlab_workspace(target_path=target_path)[0]
                                       ).split(':')[1]
         else:
             __install_package('ipyparams')
